# Copyright 2021 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import fields, models, api
from datetime import datetime, date


class NichoirsStatYear(models.Model):
    _name = 'nichoirs.stat.year'
    _description = 'Statistiques de ventes nichoirs'

    # ------------------------------------------------------
    # Fields declaration
    # ------------------------------------------------------
    categ_id = fields.Many2one(
        'product.public.category', 'Catégorie',
        required=True)
    year = fields.Integer('Année')
    product_qty = fields.Integer("Nombre d'articles vendus")
    coeff_year = fields.Integer(
        "Coefficient calculé en fonction de l'année",
        compute='_compute_coeff_year',
        store=True
    )
    nichoirs_proprata_qty = fields.Integer(
        "Nombre de nichoirs",
        compute='_compute_nichoirs_proprata_qty',
        store=True)

    # ------------------------------------------------------
    # SQL Constraints
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Default methods
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Computed fields / Search Fields
    # ------------------------------------------------------
    @api.depends('year')
    @api.multi
    def _compute_coeff_year(self):
        for res in self:
            if res.year:
                if date.today().year == res.year:
                    res.coeff_year = 1
                else:
                    res.coeff_year = date.today().year - res.year

    @api.depends('product_qty', 'coeff_year')
    @api.multi
    def _compute_nichoirs_proprata_qty(self):
        for res in self:
            if res.product_qty:
                res.nichoirs_proprata_qty = res.product_qty * res.coeff_year
                res.categ_id.update_qty()

    # ------------------------------------------------------
    # Onchange / Constraints
    # ------------------------------------------------------

    # ------------------------------------------------------
    # CRUD methods (ORM overrides)
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Actions
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Business methods
    # ------------------------------------------------------
